Learn R Programming

GeneralizedUmatrix (version 1.2.1)

TopviewTopographicMap: Topview of Topographic Map ind 2D

Description

Fast Visualization of the Generalized U-matrix in 2D which visualizes high-dimensional distance and density based structurs of the combination two-dimensional scatter plots (projections) with high-dimensional data.

Usage

TopviewTopographicMap(GeneralizedUmatrix, BestMatchingUnits,

Cls, ClsColors = NULL, Imx = NULL, Names = NULL, BmSize = 6, ...)

Arguments

GeneralizedUmatrix

(1:Lines,1:Columns), [1:Lines,1:Columns] Umatrix to be plotted, numerical matrix storing the U-heights, see [Thrun, 2018] for definition.

BestMatchingUnits

(1:n,1:2), Positions of bestmatches to be plotted onto the Umatrix

Cls

(1:n), numerical vector of classification of k classes for the bestmatch at the given point

ClsColors

Vector of colors that will be used to colorize the different classes

Imx

a mask (Imx) that will be used to cut out the umatrix

Names

If set: [1:k] character vector naming the k classes for the legend. . In this case, further parameters with the possibility to adjust are: NamesCex: (size); NamesPosition: Legend position; NamesTitle: title of legend; NamesColors: colors if ClsColors are not default (NULL).

BmSize

size(diameter) of the points in the visualizations. The points represent the BestMatchingUnits

…
Tiled

Should the Umatrix be drawn 4times?

main

set specific title in plot

ExtendBorders

scalar, extends Umatrix by toroidal continuation of the given Umatrix

_

Further Arguments relevant for interactive shiny application

Value

plotly handler

Details

Please see plotTopographicMap. This function is currently still experimental because not all functionallity is fully tested yet.

References

[Thrun, 2018] Thrun, M. C.: Projection Based Clustering through Self-Organization and Swarm Intelligence, doctoral dissertation 2017, Springer, Heidelberg, ISBN: 978-3-658-20539-3, https://doi.org/10.1007/978-3-658-20540-9, 2018.

[Thrun et al., 2016] Thrun, M. C., Lerch, F., Loetsch, J., & Ultsch, A.: Visualization and 3D Printing of Multivariate Data of Biomarkers, in Skala, V. (Ed.), International Conference in Central Europe on Computer Graphics, Visualization and Computer Vision (WSCG), Vol. 24, Plzen, http://wscg.zcu.cz/wscg2016/short/A43-full.pdf, 2016.

See Also

plotTopographicMap

Examples

Run this code
# NOT RUN {
data("Chainlink")
Data=Chainlink$Data
Cls=Chainlink$Cls
InputDistances=as.matrix(dist(Data))
res=cmdscale(d=InputDistances, k = 2, eig = TRUE, add = FALSE, x.ret = FALSE)
ProjectedPoints=as.matrix(res$points)
#see also ProjectionBasedClustering package for other common projection methods
# }
# NOT RUN {
resUmatrix=GeneralizedUmatrix(Data,ProjectedPoints)
## visualization
TopviewTopographicMap(GeneralizedUmatrix = resUmatrix$Umatrix,resUmatrix$Bestmatches)
# }

Run the code above in your browser using DataLab